;
; the lowercase ninja
;
; released by arkanix labs in april 2020
;
; www.arkanixlabs.com
;
; code and petscii by
; aNdy (CSDb id=6404)
;
; music (last ninja preview) by
; anthony lees (CSDb id=4290)
;
; testing by
; moloch (CSDb id=930)
;
; This source is formatted for the ACME cross assembler
; which can be downloaded from...
; http://sourceforge.net/projects/acme-crossass/
;
; The final build was compressed and squished using
; Exomizer 2 which can be downloaded from...
; http://hem.bredband.net/magli143/exo/

; the name and file format for the assembled program

		!to "lcninja.prg",cbm

; claw in the binary data...
		
		* = $b000
music	!binary "data\music.prg",,2

		* = $2000
		!binary "data\ninja3_chars.chr"

		* = $2800
		!binary "data\lowercase_chars.chr"				

; label assignments for keyboard control

cpra				= $dc00				; cia #1, port register a
cprb				= $dc01				; cia #1, port register b


; some more label assignments (variables)

sync				= $51				; interupt sync variable
video_type			= $52				; 0=pal, 1=ntsc
music_tmr			= $53				; timer for music frame skip on ntsc

; add a BASIC startline (SYS 16384) for auto-run after loading

		* = $0801
		!word code_entry-2
		!byte $00,$00,$9e
		!text "16384"
		!byte $00,$00,$00

; entry point for the code

		* = $4000					; hence sys 16384!
				
code_entry

; detect what machine type is being used...

start_scan
		lda $d012
chkntsc
		cmp $d012
		beq chkntsc
		bmi start_scan
		adc #$00
		lsr
		bcs isntsc
		lsr
		bcs isoldntsc
		ldx #$00					; check drean or pal
		lda #$10
chkpal
		inx
		cmp $d012
		bne chkpal
		cpx #$70
		bcc ispal
isdrean
		lda #$01
		sta video_type				; video = ntsc
		jmp detect_dun
isntsc	
		lda #$01
		sta video_type				; video = ntsc
		jmp detect_dun
isoldntsc
		lda #$01
		sta video_type				; video = ntsc
		jmp detect_dun
ispal
		lda #$00
		sta video_type				; video = pal

detect_dun
		lda #$35					; kill EVERYTHING (MWHAHA!) except $f000-$ffff
		sta $01

; stop interrupts, disable the roms and set up nmi and irq interrupt pointers	

		sei							; disable maskable IRQs		
				
; setup nmi

		lda #<nmi					; some nmi stuff
		sta $fffa
		lda #>nmi
		sta $fffb
		
; setup irq's

		lda #<int					; some irq stuff
		sta $fffe
		lda #>int
		sta $ffff

		lda #$7f
		sta $dc0d					; disable timer interrupts which can be generated by the two CIA chips
		sta $dd0d					; the kernal uses such an interrupt to flash the cursor and scan
									; the keyboard, so we better stop it

		lda $dc0d					; by reading this two registers we negate any pending CIA irqs.
		lda $dd0d					; if we don't do this, a pending CIA irq might occur after we
									; finish setting up our irq. we don't want that to happen.

		lda #$00					; starting point of raster on screen ($00)
		sta $d012

		lda #$1b					; as there are more than 256 rasterlines, the topmost bit of $d011 serves as
		sta $d011					; the 9th bit for the rasterline we want our irq to be triggered.
		
		lda #$01
		sta $d019					; clear interupt bit
		sta $d01a					; tell vicii to generate interupt

		lda #$35					; turn off basic and kernal rom thus
		sta $01						; c64 now sees RAM everywhere except at $d000-$e000

		lda #$03					; select video bank
		sta $dd00		
						
		lda #$18					; use our custom charset at $2000
		sta $d018

		cli
		
; prepare the music	driver

		lda #$00
		jsr music+$7f5	
		
; setup the screen for the very first run

		jsr clear_screen			; clear screen with subroutine
		
; print up the intro screen ram			
		
		ldx #$00					; zero x register
introram_loop						; load up whatver is in the intro
		lda intro_ram,x				; screen ram table and write to the
		sta $0400,x					; screen ram
		lda intro_ram+250,x
		sta $0400+250,x
		lda intro_ram+500,x
		sta $0400+500,x
		lda intro_ram+750,x
		sta $0400+750,x	
		inx
		cpx #$fa					; done 250 writes?
		bne introram_loop			; all written? no? loop back!
		
; print the compressed intro screen colour data to colour ram
			
		ldx #$00					; zero x register
		ldy #$00					; zero y register
introcolram_loop
		lda introcolour_ram,x		; load up a byte
		sta $d800+1,y				; store a nybble to screen
		lsr
		lsr
		lsr
		lsr
		sta $d800,y					; store the other nybble

		lda introcolour_ram+125,x
		sta $d800+251,y
		lsr
		lsr
		lsr
		lsr
		sta $d800+250,y

		lda introcolour_ram+250,x
		sta $d800+501,y
		lsr
		lsr
		lsr
		lsr
		sta $d800+500,y

		lda introcolour_ram+375,x
		sta $d800+751,y
		lsr
		lsr
		lsr
		lsr
		sta $d800+750,y

		iny
		iny
		inx
		cpx #$7d
		bne introcolram_loop
		
; wait for a space press!
		
		jsr space_press
		
; clear the intro screen

		jsr clear_screen			; clear screen with subroutine		
	
; now point the charset to the lowercase rom charset at $2800		
	
		lda #$1a
		sta $d018

; print up the petscii screen ram			
		
		ldx #$00					; zero x register
ninjascrn_loop						; load up whatver is in the intro
		lda pet_ram,x				; screen ram table and write to the
		sta $0400,x					; screen ram
		lda pet_ram+250,x
		sta $0400+250,x
		lda pet_ram+500,x
		sta $0400+500,x
		lda pet_ram+750,x
		sta $0400+750,x	
		inx
		cpx #$fa					; done 250 writes?
		bne ninjascrn_loop			; all written? no? loop back!	
	
; print the compressed petscii screen colour data to colour ram
			
		ldx #$00					; zero x register
		ldy #$00					; zero y register
petcolram_loop
		lda petcolour_ram,x			; load up a byte
		sta $d800+1,y				; store a nybble to screen
		lsr
		lsr
		lsr
		lsr
		sta $d800,y					; store the other nybble

		lda petcolour_ram+125,x
		sta $d800+251,y
		lsr
		lsr
		lsr
		lsr
		sta $d800+250,y

		lda petcolour_ram+250,x
		sta $d800+501,y
		lsr
		lsr
		lsr
		lsr
		sta $d800+500,y

		lda petcolour_ram+375,x
		sta $d800+751,y
		lsr
		lsr
		lsr
		lsr
		sta $d800+750,y

		iny
		iny
		inx
		cpx #$7d
		bne petcolram_loop			
		
; wait for a space press!
		
		jsr space_press
		
; clear the intro screen

		jsr clear_screen			; clear screen with subroutine		
	
; now point back to the ninja 3 charset at $2000		
	
		lda #$18
		sta $d018
		
; print up the greets screen ram			
		
		ldx #$00					; zero x register
greetsram_loop						; load up whatver is in the intro
		lda greets_ram,x				; screen ram table and write to the
		sta $0400,x					; screen ram
		lda greets_ram+250,x
		sta $0400+250,x
		lda greets_ram+500,x
		sta $0400+500,x
		lda greets_ram+750,x
		sta $0400+750,x	
		inx
		cpx #$fa					; done 250 writes?
		bne greetsram_loop			; all written? no? loop back!
		
; print the compressed greets screen colour data
			
		ldx #$00					; zero x register
		ldy #$00					; zero y register
greetscolram_loop
		lda greetscolour_ram,x		; load up a byte
		sta $d800+1,y				; store a nybble to screen
		lsr
		lsr
		lsr
		lsr
		sta $d800,y					; store the other nybble

		lda greetscolour_ram+125,x
		sta $d800+251,y
		lsr
		lsr
		lsr
		lsr
		sta $d800+250,y

		lda greetscolour_ram+250,x
		sta $d800+501,y
		lsr
		lsr
		lsr
		lsr
		sta $d800+500,y

		lda greetscolour_ram+375,x
		sta $d800+751,y
		lsr
		lsr
		lsr
		lsr
		sta $d800+750,y

		iny
		iny
		inx
		cpx #$7d
		bne greetscolram_loop		
		
; wait for a space press!
		
		jsr space_press		
	
; space has been pressed so reset some registers

exit_intro
		sei
		lda #$37
		sta $01

		lda #$00
		sta $d011
		sta $d020
		sta $d021
		sta $d418

; and finally reset the C64

		jmp $fce2			
												

; irq interrupt =================================

int
		pha  
		txa
		pha
		tya
		pha

		lda $d019
		and #$01
		sta $d019

; play some music!

		lda video_type				; what machine is being used
		cmp #$00					; PAL?
		beq call_music_driver		; yes? play the music!
									; no?
		ldx music_tmr				; load music timer
		inx							; increase it
		cpx #$06					; is it 8?
		bne	music_play				; no? play music!
									; yes?
		ldx #$00					; reset the timer
		stx music_tmr				; then skip playing
									; the music on this occasion
		jmp set_sync				; to slow it for ntsc!

music_play
		stx	music_tmr
		
call_music_driver
		jsr music+$844

; set sync variable for main line code synchronisation

set_sync
		lda #$01					; set the sync flag to '1'		
		sta sync					; so the main code runs!
		
		pla
		tay
		pla
		tax
		pla
nmi		rti

; end irq interrupt =============================


; subroutines ===================================


; clear the screen!

clear_screen
		lda #$00
		sta $d020
		sta $d021
		tax
		ldx #$00
clsloop
		lda #$a0
		sta $0400,x
		sta $0400+250,x
		sta $0400+500,x
		sta $0400+750,x
		lda #$00
		sta $d800,x
		sta $d800+250,x
		sta $d800+500,x
		sta $d800+750,x	
		inx
		cpx #$fa
		bne clsloop
		
		rts		

; space press detect subroutine -----------------------------

space_press
	
		lda #$7f 					; load $dc00...
		sta cpra					; ...with bit row 7
		
		lda cprb					; load $dc01 to test...
		cmp #$ef					; space key pressed?
		bne space_press
		
		jsr key_debounce

		rts
		
; debounce subroutines for keyboard -------------------

key_debounce		
		lda cprb						; is there a keypress still?
		cmp #$ff						; an idiot is still pressing something???
		bne key_debounce				; lock them in a loop till they stop!!
		
		rts

; irq sync wait subroutine ---------------------------------- 
	   	 
sync_wait								; wait for sync update in irq code!
		lda #$00						; waits until the sync flag is
		sta sync						; set at the end of the interupt
sw_loop									; code further down.
		cmp sync						; no code in the main loop above
		beq sw_loop						; is executed until the interupt
										; has run it's course!
		rts

; a sync wait delay subroutine ---------------------------------- 		
		
sync_wait_long						
		jsr sync_wait
		dey
		bne sync_wait_long

		rts							
			   	
; end subroutines ===============================


; data tables here! ==========================

; intro screen ram data

intro_ram
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$01,$41,$12,$52,$0B,$4B,$01,$41,$0E,$4E,$09,$18,$58,$20,$09,$20,$01,$41,$02,$42,$13,$53,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$21,$61,$32,$72,$2B,$6B,$21,$61,$2E,$6E,$29,$38,$78,$20,$2C,$6C,$21,$61,$22,$62,$33,$73,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$90,$20,$92,$20,$85,$20,$93,$20,$85,$20,$8E,$20,$94,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$94,$20,$88,$20,$85,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$0C,$20,$20,$0F,$4F,$20,$17,$57,$20,$05,$45,$20,$12,$52,$20,$03,$43,$20,$01,$41,$20,$13,$53,$20,$05,$45,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$2C,$6C,$20,$2F,$6F,$20,$37,$77,$20,$25,$65,$20,$32,$72,$20,$23,$63,$20,$21,$61,$20,$33,$73,$20,$25,$65,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$0E,$4E,$20,$09,$20,$0E,$4E,$20,$20,$4A,$20,$01,$41,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$2E,$6E,$20,$29,$20,$2E,$6E,$20,$2A,$6A,$20,$21,$61,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$83,$8F,$84,$85,$20,$20,$81,$8E,$84,$99,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$90,$85,$94,$93,$83,$89,$89,$20,$20,$81,$8E,$84,$99,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$8D,$95,$93,$89,$83,$20,$20,$81,$8E,$94,$88,$8F,$8E,$99,$20,$8C,$85,$85,$93,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$92,$89,$90,$90,$85,$84,$20,$83,$88,$81,$92,$93,$85,$94,$20,$20,$8C,$81,$93,$94,$20,$8E,$89,$8E,$8A,$81,$20,$9C,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$90,$92,$85,$93,$93,$20,$93,$90,$81,$83,$85,$20,$86,$8F,$92,$20,$81,$20,$90,$85,$94,$93,$83,$89,$89,$9B,$9B,$9B,$20,$20,$20,$20,$20,$20

introcolour_ram
!byte $00,$00,$00,$00,$0E,$EE,$EE,$EE,$EE,$EE,$EE,$0E,$0E,$EE,$EE,$E0,$00,$00,$00,$00
!byte $00,$00,$00,$00,$04,$44,$44,$44,$44,$44,$44,$04,$44,$44,$44,$40,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$06,$06,$06,$06,$06,$06,$06,$10,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$22,$20,$20,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$0A,$00,$AA,$0A,$A0,$AA,$0A,$A0,$AA,$0A,$A0,$AA,$0A,$A0,$20,$00,$00
!byte $00,$00,$00,$02,$20,$22,$02,$20,$22,$02,$20,$22,$02,$20,$22,$02,$20,$20,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$22,$22,$AA,$0A,$0A,$A0,$0A,$0A,$A0,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$22,$02,$02,$20,$22,$02,$20,$20,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$05,$55,$50,$0D,$DD,$D0,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$55,$55,$55,$50,$0D,$DD,$D0,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$55,$55,$50,$0D,$DD,$DD,$DD,$AD,$DD,$D0,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$05,$55,$55,$50,$55,$55,$55,$50,$0D,$DD,$D0,$DD,$DD,$D0,$D0,$00,$00,$00
!byte $00,$02,$00,$50,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$22,$22,$20,$22,$22,$20,$22,$20,$20,$22,$22,$22,$22,$22,$00,$00,$00

; petscii screen ram data

pet_ram
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$2C,$2E,$68,$E6,$66,$5C,$68,$2D,$68,$2C,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$64,$6F,$6F,$64,$64,$20,$20,$2E,$68,$2D,$E6,$68,$3A,$68,$27,$20,$20,$64,$64,$6F,$6F,$64,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$6C,$62,$A0,$BB,$AE,$DC,$A2,$A2,$F7,$62,$62,$79,$6F,$64,$64,$6F,$79,$62,$62,$F7,$A2,$A2,$DC,$AE,$BB,$A0,$62,$7B,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$6C,$EC,$22,$78,$22,$78,$E2,$F9,$E8,$BB,$B0,$A0,$BB,$DC,$A0,$A2,$DC,$A0,$A1,$AE,$BA,$E8,$F9,$E2,$78,$22,$78,$22,$FB,$7B,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$2E,$22,$6C,$68,$68,$F8,$68,$62,$68,$20,$7C,$E8,$AE,$E6,$FE,$A0,$BA,$FF,$AE,$B0,$E8,$7E,$20,$68,$62,$68,$F8,$68,$68,$7B,$22,$2E,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$FF,$E2,$F9,$F9,$BA,$A0,$BB,$E8,$A2,$7B,$20,$FB,$DC,$A0,$A0,$AE,$A1,$DC,$EC,$20,$6C,$A2,$E8,$BB,$A0,$BA,$F9,$F9,$E2,$7F,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$FF,$6C,$66,$7B,$68,$20,$22,$77,$78,$78,$E2,$7F,$20,$FB,$AE,$E8,$DC,$E8,$EC,$20,$FF,$E2,$78,$78,$77,$22,$20,$68,$6C,$5E,$7B,$7F,$20,$20,$20,$20
!byte $20,$20,$20,$FE,$61,$66,$E6,$61,$66,$7B,$20,$7E,$66,$5C,$66,$7B,$7F,$E1,$E8,$BB,$A2,$E8,$61,$FF,$6C,$5E,$E1,$5E,$7C,$20,$6C,$5E,$E1,$DE,$5E,$20,$FC,$20,$20,$20
!byte $20,$20,$20,$5E,$A0,$7B,$E2,$66,$7C,$66,$68,$66,$E6,$6C,$E6,$66,$7B,$FE,$A0,$A0,$A0,$A0,$FC,$6C,$5E,$DE,$7B,$DE,$5E,$68,$5E,$7E,$5E,$E2,$6C,$A0,$5E,$20,$20,$20
!byte $20,$20,$20,$FB,$E6,$A0,$FC,$79,$79,$6F,$6F,$6F,$6F,$79,$62,$62,$79,$EC,$78,$77,$77,$78,$FB,$79,$62,$62,$79,$6F,$6F,$6F,$6F,$79,$79,$FE,$A0,$DE,$EC,$20,$20,$20
!byte $20,$20,$20,$20,$E2,$E8,$EF,$E4,$E8,$E8,$BB,$E4,$EF,$EF,$E8,$22,$7E,$2E,$68,$E6,$25,$68,$2E,$7C,$22,$E8,$EF,$EF,$E4,$BB,$E8,$E8,$E4,$EF,$E8,$E2,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$63,$63,$63,$20,$20,$20,$20,$20,$2E,$68,$68,$2E,$68,$68,$2E,$20,$20,$20,$20,$20,$20,$63,$63,$63,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$54,$20,$20,$20,$20,$20,$48,$20,$20,$20,$20,$20,$45,$20,$20,$20,$20,$20,$20,$4C,$20,$20,$20,$20,$20,$41,$20,$20,$20,$20,$20,$53,$20,$20,$20,$20,$20,$54,$20
!byte $20,$20,$6C,$20,$20,$20,$20,$20,$20,$7B,$20,$20,$7B,$20,$20,$20,$6C,$20,$20,$20,$20,$20,$20,$7B,$20,$6C,$20,$20,$20,$20,$6C,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$76,$FC,$6C,$20,$20,$20,$76,$61,$20,$20,$DC,$74,$20,$20,$76,$FC,$6C,$20,$20,$20,$76,$61,$20,$76,$FC,$20,$20,$20,$76,$FC,$7F,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$67,$DC,$74,$FC,$20,$20,$FE,$5C,$20,$67,$DC,$75,$20,$20,$67,$DC,$74,$FC,$20,$20,$FE,$5C,$20,$67,$DC,$74,$20,$20,$67,$DC,$74,$FC,$20,$20,$20,$20,$20,$20
!byte $20,$20,$6A,$DC,$5C,$7C,$FC,$20,$FB,$5C,$20,$67,$E6,$61,$20,$20,$6A,$DC,$5C,$7C,$FC,$20,$FB,$5C,$20,$6A,$DC,$5C,$20,$20,$6A,$DC,$5C,$7C,$FC,$20,$6C,$20,$20,$20
!byte $20,$20,$67,$E8,$FC,$20,$FB,$7F,$E1,$FC,$20,$E1,$DC,$FC,$20,$20,$67,$E8,$FC,$20,$FB,$7F,$E1,$FC,$20,$67,$E8,$FC,$20,$20,$67,$E8,$FC,$20,$FB,$7F,$FB,$FC,$20,$20
!byte $20,$20,$76,$DC,$E6,$65,$20,$DC,$FC,$7C,$20,$E1,$E8,$DC,$74,$20,$76,$DC,$E6,$65,$20,$DC,$FC,$7C,$20,$76,$DC,$E6,$65,$20,$76,$DC,$E6,$65,$20,$DC,$FC,$FB,$7E,$20
!byte $20,$20,$E1,$E8,$DC,$65,$20,$E1,$E6,$E6,$7B,$E1,$DC,$E6,$FC,$20,$E1,$E8,$DC,$65,$20,$E1,$E6,$E6,$7B,$E1,$E8,$DC,$65,$20,$E1,$E8,$DC,$65,$FE,$E1,$E6,$E6,$20,$20
!byte $20,$20,$FE,$E6,$BA,$65,$20,$7C,$E6,$E8,$61,$7C,$E6,$DC,$E8,$20,$FE,$E6,$BA,$65,$20,$7C,$E6,$E8,$61,$FE,$E6,$BA,$65,$20,$FE,$E6,$BA,$65,$20,$67,$DC,$DC,$5C,$20
!byte $20,$67,$DC,$DC,$E6,$65,$20,$20,$E8,$EC,$20,$20,$FB,$E8,$EC,$67,$DC,$DC,$E6,$65,$20,$20,$E8,$EC,$67,$DC,$DC,$E6,$65,$67,$DC,$DC,$E6,$65,$20,$FE,$DC,$BA,$DC,$20
!byte $20,$FE,$DC,$BB,$DC,$65,$20,$20,$20,$20,$20,$20,$20,$20,$20,$FE,$DC,$BB,$DC,$65,$20,$20,$20,$20,$FE,$DC,$BB,$DC,$65,$FE,$DC,$BB,$DC,$65,$20,$7C,$A0,$DC,$EC,$20
!byte $20,$7C,$BB,$DC,$EC,$20,$20,$20,$01,$4E,$04,$19,$20,$20,$20,$7C,$BB,$DC,$EC,$20,$20,$20,$20,$20,$7C,$BB,$DC,$EC,$20,$7C,$BB,$DC,$EC,$20,$20,$20,$7C,$E2,$20,$20
		
; main colour ram data

petcolour_ram
!byte $00,$22,$22,$22,$22,$22,$22,$2B,$CB,$BC,$CC,$BB,$B2,$22,$22,$22,$22,$22,$00,$00
!byte $00,$00,$00,$00,$0A,$AA,$AA,$00,$BB,$CC,$CB,$BB,$02,$AA,$AA,$A2,$22,$00,$00,$00
!byte $00,$00,$FF,$8A,$AA,$AA,$AA,$AA,$AA,$AA,$AA,$AA,$AA,$AA,$AA,$AA,$A8,$00,$00,$00
!byte $00,$00,$FA,$AA,$AA,$AA,$AA,$AE,$AA,$AA,$AA,$AA,$AA,$AA,$AA,$AA,$AA,$A0,$00,$00
!byte $00,$00,$9A,$AA,$AA,$AA,$A0,$AA,$AA,$AA,$AA,$AE,$AA,$0A,$AA,$AA,$AA,$A9,$00,$00
!byte $00,$09,$0A,$AA,$AA,$AA,$AA,$AA,$AA,$AA,$AA,$AA,$AA,$AA,$AA,$AA,$AA,$A0,$00,$00
!byte $00,$00,$8C,$FC,$9A,$AA,$AA,$AA,$0A,$AA,$AA,$A0,$AA,$AA,$AA,$A9,$CF,$C8,$00,$00
!byte $00,$08,$AC,$FF,$59,$01,$59,$FC,$AA,$AA,$AA,$AA,$CF,$95,$10,$95,$FF,$C0,$80,$00
!byte $00,$08,$A2,$CF,$95,$55,$9F,$FC,$CA,$AA,$AA,$AC,$CF,$F9,$55,$59,$FC,$2A,$80,$00
!byte $00,$08,$AA,$AA,$AA,$AA,$AA,$AA,$AA,$88,$88,$AA,$AA,$AA,$AA,$AA,$AA,$AA,$80,$00
!byte $00,$0A,$88,$AA,$AA,$AA,$AA,$AA,$8B,$CC,$BB,$B8,$AA,$AA,$AA,$AA,$AA,$88,$00,$00
!byte $00,$00,$00,$80,$88,$80,$80,$00,$BB,$CC,$CB,$B0,$00,$08,$08,$88,$88,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$BB,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $0F,$F0,$0F,$FF,$0F,$0F,$0F,$00,$00,$FF,$F0,$0F,$00,$F0,$F0,$00,$FF,$00,$00,$F0
!byte $00,$C0,$00,$00,$0C,$00,$C0,$00,$C0,$00,$00,$0C,$0F,$00,$00,$F0,$00,$00,$00,$00
!byte $00,$CF,$F0,$00,$CF,$00,$FB,$00,$CF,$F0,$00,$CF,$0C,$F0,$00,$CF,$F0,$00,$CF,$00
!byte $00,$CF,$CF,$00,$FF,$0C,$FF,$00,$CF,$CF,$00,$FF,$0C,$FC,$00,$CF,$CF,$00,$FF,$00
!byte $00,$BF,$FC,$F0,$AA,$0F,$FF,$00,$BF,$FC,$F0,$AA,$0B,$FF,$00,$BF,$FC,$F0,$2A,$00
!byte $00,$CF,$A0,$CF,$22,$0A,$AA,$00,$CF,$A0,$CF,$22,$0C,$FA,$00,$CF,$A0,$CF,$22,$00
!byte $00,$2A,$A2,$0A,$A2,$02,$AA,$20,$2A,$A2,$0A,$A2,$02,$AA,$20,$2A,$A2,$0A,$A2,$20
!byte $00,$2A,$A2,$02,$A2,$22,$22,$20,$2A,$A2,$02,$A2,$22,$AA,$20,$2A,$A2,$22,$A2,$20
!byte $00,$22,$22,$02,$22,$22,$22,$20,$22,$22,$02,$22,$22,$22,$20,$22,$22,$02,$22,$22
!byte $02,$22,$22,$00,$22,$20,$22,$22,$22,$22,$00,$22,$22,$22,$22,$22,$22,$02,$22,$22
!byte $02,$22,$22,$00,$00,$00,$00,$02,$22,$22,$00,$00,$22,$22,$22,$22,$22,$02,$22,$20
!byte $02,$22,$20,$00,$22,$22,$22,$02,$22,$20,$22,$22,$22,$22,$02,$22,$20,$00,$22,$00

; greets screen ram data

greets_ram
!byte $01,$41,$12,$52,$0B,$4B,$01,$41,$0E,$4E,$09,$18,$58,$20,$09,$20,$01,$41,$02,$42,$13,$53,$20,$07,$47,$12,$52,$05,$45,$05,$45,$14,$54,$09,$0E,$4E,$07,$47,$13,$53
!byte $21,$61,$32,$72,$2B,$6B,$21,$61,$2E,$6E,$29,$38,$78,$20,$2C,$6C,$21,$61,$22,$62,$33,$73,$20,$27,$67,$32,$72,$25,$65,$25,$65,$34,$74,$29,$2E,$6E,$27,$67,$33,$73
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$81,$82,$93,$85,$8E,$83,$85,$20,$20,$20,$20,$81,$82,$99,$93,$93,$20,$83,$8F,$8E,$8E,$85,$83,$94,$89,$8F,$8E,$20,$20,$20,$81,$92,$94,$93,$94,$81,$94,$85,$20
!byte $81,$94,$85,$20,$82,$89,$94,$20,$20,$81,$94,$8C,$81,$8E,$94,$89,$93,$20,$20,$82,$8F,$8F,$9A,$85,$20,$84,$85,$93,$89,$87,$8E,$20,$20,$83,$81,$8D,$85,$8C,$8F,$94
!byte $83,$85,$8E,$93,$8F,$92,$20,$84,$85,$93,$89,$87,$8E,$20,$20,$83,$88,$8F,$92,$95,$93,$20,$20,$83,$88,$92,$8F,$8D,$85,$20,$20,$83,$8E,$83,$84,$20,$20,$83,$90,$95
!byte $20,$83,$8F,$93,$89,$8E,$85,$20,$20,$83,$92,$85,$93,$83,$85,$8E,$94,$20,$20,$83,$92,$85,$93,$94,$20,$20,$83,$8F,$96,$85,$92,$94,$20,$82,$89,$94,$8F,$90,$93,$20
!byte $20,$84,$85,$86,$85,$8E,$83,$85,$20,$86,$8F,$92,$83,$85,$20,$20,$20,$84,$85,$8B,$81,$84,$85,$8E,$83,$85,$20,$20,$84,$85,$93,$89,$92,$85,$20,$20,$84,$81,$83,$20
!byte $20,$84,$8D,$81,$87,$89,$83,$20,$20,$85,$98,$83,$8C,$95,$93,$89,$96,$85,$20,$8F,$8E,$20,$20,$20,$86,$81,$89,$92,$8C,$89,$87,$88,$94,$20,$20,$86,$9D,$83,$87,$20
!byte $86,$89,$92,$85,$20,$20,$86,$8C,$81,$94,$9C,$20,$20,$86,$8F,$83,$95,$93,$20,$20,$86,$92,$85,$8E,$83,$88,$20,$94,$8F,$95,$83,$88,$20,$20,$88,$89,$94,$8D,$85,$8E
!byte $88,$8F,$81,$98,$85,$92,$93,$20,$20,$20,$88,$8F,$8B,$95,$94,$8F,$20,$86,$8F,$92,$83,$85,$20,$20,$20,$20,$8C,$85,$87,$89,$8F,$8E,$20,$8F,$86,$20,$84,$8F,$8F,$8D
!byte $20,$8D,$81,$8E,$89,$81,$83,$93,$20,$8F,$86,$20,$8E,$8F,$89,$93,$85,$20,$20,$20,$20,$8D,$81,$99,$84,$81,$99,$20,$20,$20,$20,$8D,$85,$81,$8E,$94,$85,$81,$8D,$20
!byte $20,$20,$8D,$85,$94,$81,$8C,$96,$8F,$94,$85,$20,$20,$8E,$8F,$8E,$81,$8D,$85,$20,$20,$8E,$8F,$93,$94,$81,$8C,$87,$89,$81,$20,$20,$8E,$95,$81,$8E,$83,$85,$20,$20
!byte $20,$8F,$86,$86,$85,$8E,$83,$85,$20,$20,$8F,$8E,$93,$8C,$81,$95,$87,$88,$94,$20,$20,$8F,$92,$82,$20,$20,$8F,$98,$99,$92,$8F,$8E,$20,$20,$90,$81,$84,$95,$81,$20
!byte $20,$20,$20,$90,$85,$92,$86,$8F,$92,$8D,$85,$92,$93,$20,$20,$90,$8C,$95,$93,$88,$20,$20,$90,$90,$83,$93,$20,$20,$90,$93,$99,$94,$92,$8F,$8E,$89,$8B,$20,$20,$20
!byte $92,$85,$90,$94,$89,$8C,$89,$81,$20,$20,$92,$85,$93,$8F,$95,$92,$83,$85,$20,$20,$92,$87,$83,$84,$20,$20,$93,$85,$83,$95,$92,$85,$20,$20,$93,$88,$81,$90,$85,$20
!byte $20,$20,$93,$89,$84,$85,$20,$82,$20,$20,$20,$93,$89,$8E,$87,$95,$8C,$81,$92,$20,$20,$93,$8C,$81,$93,$88,$20,$20,$93,$8C,$89,$90,$93,$94,$92,$85,$81,$8D,$20,$20
!byte $20,$93,$95,$83,$83,$85,$93,$93,$20,$81,$8E,$84,$20,$94,$92,$83,$20,$20,$93,$94,$99,$8C,$85,$20,$20,$93,$95,$89,$83,$99,$8F,$20,$89,$8E,$84,$95,$93,$94,$9B,$20
!byte $20,$20,$20,$20,$94,$81,$92,$91,$95,$81,$92,$94,$20,$20,$20,$94,$85,$8D,$90,$85,$93,$94,$20,$20,$20,$94,$85,$8B,$20,$20,$20,$94,$92,$89,$81,$84,$20,$20,$20,$20
!byte $94,$92,$89,$93,$94,$81,$92,$20,$81,$8E,$84,$20,$92,$85,$84,$20,$93,$85,$83,$94,$8F,$92,$20,$20,$20,$96,$89,$92,$95,$9A,$20,$20,$20,$96,$89,$93,$89,$8F,$8E,$20
!byte $20,$97,$8F,$97,$20,$20,$20,$97,$92,$81,$89,$94,$88,$20,$84,$85,$93,$89,$87,$8E,$93,$20,$20,$20,$98,$85,$8E,$8F,$8E,$20,$20,$20,$98,$85,$8E,$94,$81,$98,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$81,$8E,$84,$20,$81,$8E,$99,$8F,$8E,$85,$20,$85,$8C,$93,$85,$20,$97,$85,$20,$86,$8F,$92,$87,$8F,$94,$9B,$9B,$9B,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$97,$97,$97,$9B,$81,$92,$8B,$81,$8E,$89,$98,$8C,$81,$82,$93,$9B,$83,$8F,$8D,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20

; greets colour ram

greetscolour_ram
!byte $EE,$EE,$EE,$EE,$EE,$EE,$E0,$E0,$EE,$EE,$EE,$0E,$EE,$EE,$EE,$EE,$EE,$EE,$EE,$EE
!byte $44,$44,$44,$44,$44,$44,$40,$44,$44,$44,$44,$04,$44,$44,$44,$44,$44,$44,$44,$44
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $01,$11,$11,$11,$01,$00,$11,$11,$10,$11,$11,$11,$11,$11,$00,$01,$11,$11,$11,$10
!byte $FF,$F0,$FF,$F0,$0F,$FF,$FF,$FF,$F0,$0F,$FF,$FF,$0F,$FF,$FF,$F1,$1F,$FF,$FF,$FF
!byte $CC,$CC,$CC,$0C,$CC,$CC,$C0,$0C,$CC,$CC,$C0,$0C,$CC,$CC,$C0,$1C,$CC,$C0,$0C,$CC
!byte $0B,$BB,$BB,$B1,$1B,$BB,$BB,$BB,$B1,$1B,$BB,$BB,$11,$BB,$BB,$BB,$1B,$BB,$BB,$B0
!byte $03,$33,$33,$33,$13,$33,$33,$11,$03,$33,$33,$33,$33,$01,$33,$33,$33,$11,$33,$30
!byte $0E,$EE,$EE,$E0,$0E,$EE,$EE,$EE,$EE,$0E,$E0,$00,$EE,$EE,$EE,$EE,$EB,$EE,$EE,$E0
!byte $44,$44,$00,$44,$44,$40,$04,$44,$44,$00,$44,$44,$44,$04,$44,$44,$0B,$44,$44,$44
!byte $66,$66,$66,$60,$00,$66,$66,$66,$06,$66,$66,$00,$00,$66,$66,$66,$06,$60,$66,$66
!byte $07,$77,$77,$77,$07,$70,$77,$77,$70,$00,$07,$77,$77,$70,$00,$07,$77,$77,$77,$70
!byte $00,$88,$88,$88,$88,$80,$08,$88,$88,$82,$28,$88,$88,$88,$88,$11,$88,$88,$88,$00
!byte $09,$99,$99,$99,$00,$99,$99,$99,$99,$90,$09,$99,$11,$99,$99,$99,$11,$99,$99,$90
!byte $00,$0D,$DD,$DD,$DD,$DD,$D0,$0D,$DD,$DD,$00,$DD,$DD,$01,$DD,$DD,$DD,$DD,$D0,$00
!byte $FF,$FF,$FF,$FF,$00,$FF,$FF,$FF,$FF,$11,$FF,$FF,$10,$FF,$FF,$FF,$00,$FF,$FF,$F0
!byte $00,$55,$55,$05,$00,$05,$55,$55,$55,$51,$15,$55,$55,$11,$55,$55,$55,$55,$55,$00
!byte $01,$11,$11,$11,$01,$11,$11,$11,$11,$11,$11,$10,$01,$11,$11,$10,$11,$11,$11,$10
!byte $00,$00,$FF,$FF,$FF,$FF,$01,$0F,$FF,$FF,$FF,$11,$0F,$FF,$11,$0F,$FF,$FF,$00,$00
!byte $CC,$CC,$CC,$C0,$CC,$C0,$CC,$C0,$CC,$CC,$CC,$00,$0C,$CC,$CC,$00,$0C,$CC,$CC,$C0
!byte $0B,$BB,$00,$0B,$BB,$BB,$B0,$BB,$BB,$BB,$B1,$10,$BB,$BB,$B1,$10,$BB,$BB,$BB,$00
!byte $00,$00,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$00,$00,$00
!byte $00,$00,$00,$77,$72,$77,$77,$77,$07,$77,$70,$77,$07,$77,$77,$77,$77,$00,$00,$00
!byte $00,$00,$10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$33,$33,$33,$33,$33,$33,$33,$33,$33,$31,$11,$11,$00,$00,$00

